<?xml version="1.0" encoding="UTF-8" ?>
<!DOCTYPE modulesynopsis SYSTEM "../style/modulesynopsis.dtd">
<?xml-stylesheet type="text/xsl" href="../style/manual.fr.xsl"?>
<!-- English Revision: 1751352 -->
<!-- French translation : Lucien GENTIS -->
<!-- Reviewed by : Vincent Deffontaines -->

<!--
 Licensed to the Apache Software Foundation (ASF) under one or more
 contributor license agreements.  See the NOTICE file distributed with
 this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->

<modulesynopsis metafile="mod_authz_dbm.xml.meta">

<name>mod_authz_dbm</name>
<description>Autorisation par groupes sur base de fichiers DBM</description>
<status>Extension</status>
<sourcefile>mod_authz_dbm.c</sourcefile>
<identifier>authz_dbm_module</identifier>

<summary>
    <p>Ce module propose d'autoriser ou d'interdire l'accès à certaines
    zones du site web aux utilisateurs authentifiés en fonction de leur
    appartenance à un groupe spécifié. Le module
    <module>mod_authz_groupfile</module> fournit une fonctionnalité
    similaire.</p>
</summary>

<seealso><directive module="mod_authz_core">Require</directive></seealso>

<section id="requiredirectives"><title>The Require Directives</title>

    <p>Les directives <directive
    module="mod_authz_core">Require</directive> d'Apache permettent,
    au cours de la phase d'autorisation, de s'assurer qu'un utilisateur
    est bien autorisé à accéder à une ressource.  mod_authz_dbm ajoute
    les types d'autorisation <code>dbm-group</code> et <code>dbm-file-group</code>.</p>

    <p>A partir de la version 2.4.8, les directives require DBM
    supportent les <a href="../expr.html">expressions</a>.</p>

<section id="reqgroup"><title>Require dbm-group</title>

    <p>Cette directive permet de spécifier à quel groupe un utilisateur
    doit appartenir pour obtenir l'autorisation d'accès.</p>

    <highlight language="config">
      Require dbm-group admin
    </highlight>

</section>

<section id="reqfilegroup"><title>Require dbm-file-group</title>

    <p>Lorsque cette directive est définie, l'utilisateur doit
    appartenir au groupe du fichier pour pouvoir y accéder.</p>

    <highlight language="config">
      Require dbm-file-group
    </highlight>

</section>

</section>

<section id="examples">
<title>Exemple d'utilisation</title>
<p><em>Notez que si vous utilisez mod_authz_dbm, le mot-clé pour les
groupes d'authentification qui était auparavant <code>group</code> est
maintenant <code>dbm-group</code> :</em>
</p>
<highlight language="config">
&lt;Directory "/foo/bar"&gt;
  AuthType Basic
  AuthName "Secure Area"
  AuthBasicProvider dbm
  AuthDBMUserFile "site/data/users"
  AuthDBMGroupFile "site/data/users"
  Require dbm-group admin
&lt;/Directory&gt;
</highlight>
</section>

<directivesynopsis>
<name>AuthDBMGroupFile</name>
<description>Définit le nom du fichier de base de données qui liste
les groupes d'utilisateurs.</description>
<syntax>AuthDBMGroupFile <var>chemin-fichier</var></syntax>
<contextlist><context>directory</context><context>.htaccess</context>
</contextlist>
<override>AuthConfig</override>

<usage>
    <p>La directive <directive>AuthDBMGroupFile</directive> définit
    le nom d'un fichier DBM contenant la liste des groupes
    d'utilisateurs, destinés à la gestion des autorisations.
    <var>chemin-fichier</var> est le chemin absolu du
    fichier de groupes.</p>

    <p>La clé du fichier de groupes est le nom d'utilisateur. La valeur
    de chaque clé est la liste des groupes, séparés par des virgules,
    auxquels l'utilisateur appartient. Cette liste ne doit comporter
    ni espace, ni caractère ':'.</p>

    <note type="warning"><title>Sécurité</title>
      <p>Le fichier spécifié par la directive
<directive>AuthDBMGroupFile</directive> doit être situé en dehors de
l'arborescence des documents du serveur web. Ne le placez
<strong>surtout pas</strong> dans le répertoire qu'il protège, faute
de quoi, les clients pourraient le télécharger, en l'abscence de
protection supplémentaire.</p>
    </note>

    <p>Utilisation combinée de fichiers DBM de groupes et de mots de
    passe : dans certains cas, il est plus simple de gérer une seule
    base de données contenant les groupes et mots de passe de chaque
    utilisateur. L'écriture de programmes de support en est ainsi
    simplifiée car ils n'ont plus qu'un seul fichier DBM à gérer et
    à verrouiller. Pour ce faire, on attribue le même nom de fichier
    DBM aux fichiers de groupes et de mots de passe :</p>

    <highlight language="config">
AuthDBMGroupFile "/www/userbase"
AuthDBMUserFile "/www/userbase"
    </highlight>

    <p>La clé du fichier DBM unique est le nom d'utilisateur. La
    valeur associée à la clé contient :</p>

    <example>
      Mot de passe chiffré : Liste de groupes [ : (ignoré) ]
    </example>

    <p>La partie mot de passe contient comme d'habitude le mot de
    passe chiffré. Viennent ensuite le caractère ':' et la liste des
    groupes séparés par des virgules. Il est possible d'ajouter
    d'autres données en fin de ligne après un autre caractère ':',
    mais elles seront ignorées par le module d'autorisation.</p>
</usage>
</directivesynopsis>

<directivesynopsis>
<name>AuthzDBMType</name>
<description>Définit le type de fichier de base de données contenant
la liste des groupes d'utilisateurs</description>
<syntax>AuthzDBMType default|SDBM|GDBM|NDBM|DB</syntax>
<default>AuthzDBMType default</default>
<contextlist><context>directory</context><context>.htaccess</context>
</contextlist>
<override>AuthConfig</override>

<usage>
    <p>Définit le type de fichier de base de données contenant la
    liste des groupes d'utilisateurs. Le type de base de données par
    défaut est déterminé à la compilation. Les autres types de bases
    de données disponibles dépendent aussi de la
    <a href="../install.html#dbm">configuration de la
    compilation</a>.</p>

    <p>Quel que soit le programme que vous utilisez pour créer votre
    fichier de groupes, il est impératif que celui-ci soit configuré
    pour utiliser le même type de base de données.</p>
</usage>
</directivesynopsis>

</modulesynopsis>
