<?xml version="1.0"?>
<!DOCTYPE modulesynopsis SYSTEM "../style/modulesynopsis.dtd">
<?xml-stylesheet type="text/xsl" href="../style/manual.fr.xsl"?>
<!-- English Revision : 1421821 -->
<!-- French translation : Lucien GENTIS -->
<!-- $LastChangedRevision: 2012121601 $ -->

<!--
 Licensed to the Apache Software Foundation (ASF) under one or more
 contributor license agreements.  See the NOTICE file distributed with
 this work for additional information regarding copyright ownership.
 The ASF licenses this file to You under the Apache License, Version 2.0
 (the "License"); you may not use this file except in compliance with
 the License.  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
-->

<modulesynopsis metafile="mod_version.xml.meta">
<name>mod_version</name>
<description>Configuration d&eacute;pendant de la version</description>
<status>Extension</status>
<sourcefile>mod_version.c</sourcefile>
<identifier>version_module</identifier>

<summary>
    <p>Ce module a &eacute;t&eacute; con&ccedil;u pour &ecirc;tre utilis&eacute; dans les suites de tests
    et les grands r&eacute;seaux qui doivent prendre en compte diff&eacute;rentes
    versions de httpd et diff&eacute;rentes configurations. Il fournit un
    nouveau conteneur -- <directive type="section"
    module="mod_version">IfVersion</directive>, qui apporte une grande
    souplesse dans la v&eacute;rification de version en permettant une
    comparaison num&eacute;rique et l'utilisation d'expressions
    rationnelles.</p>

    <example><title>Exemples</title>
      <highlight language="config">
&lt;IfVersion 2.4.2&gt;
    # la version actuelle de httpd est exactement 2.4.2
&lt;/IfVersion&gt;

&lt;IfVersion >= 2.5&gt;
    # utilise vraiment les nouvelles fonctionnalit&eacute;s :-)
&lt;/IfVersion&gt;
      </highlight>
    </example>

    <p>Voir ci-dessous pour d'autres exemples.</p>
</summary>

<directivesynopsis type="section">
<name>IfVersion</name>
<description>Contient des portions de configuration d&eacute;pendantes de la
version</description>
<syntax>&lt;IfVersion [[!]<var>op&eacute;rateur</var>] <var>version</var>&gt; ...
&lt;/IfVersion&gt;</syntax>
<contextlist><context>server config</context><context>virtual host
</context>
<context>directory</context><context>.htaccess</context></contextlist>
<override>All</override>

<usage>
    <p>La section <directive type="section">IfVersion</directive>
    rassemble des directives de configuration qui ne sont ex&eacute;cut&eacute;es que
    si la version de httpd satisfait aux crit&egrave;res sp&eacute;cifi&eacute;s. Pour une
    comparaison normale (num&eacute;rique), l'argument <var>version</var> doit
    &ecirc;tre sp&eacute;cifi&eacute; sous le format
    <code><var>majeur</var>[.<var>mineur</var>[.<var>patch</var>]]</code>,
    comme par exemple <code>2.1.0</code> ou <code>2.2</code>.
    <var>mineur</var> et <var>patch</var> sont optionnels. Si ces
    num&eacute;ros sont absents, il se voient affect&eacute;e implicitement la valeur
    0. Les <var>op&eacute;rateur</var>s num&eacute;riques suivants sont autoris&eacute;s
    :</p>

    <table style="zebra" border="1">
    <tr><th><var>op&eacute;rateur</var></th><th>description</th></tr>
    <tr><td><code>=</code> ou <code>==</code></td>
        <td>La version de httpd est &eacute;gale &agrave; la valeur
	sp&eacute;cifi&eacute;e</td></tr>
    <tr><td><code>&gt;</code></td>
        <td>La version de httpd est sup&eacute;rieure &agrave; la valeur
	sp&eacute;cifi&eacute;e</td></tr>
    <tr><td><code>&gt;=</code></td>
        <td>La version de httpd est sup&eacute;rieure ou &eacute;gale &agrave; la valeur
	sp&eacute;cifi&eacute;e</td></tr>
    <tr><td><code>&lt;</code></td>
        <td>La version de httpd est inf&eacute;rieure &agrave; la valeur
	sp&eacute;cifi&eacute;e</td></tr>
    <tr><td><code>&lt;=</code></td>
        <td>La version de httpd est inf&eacute;rieure ou &eacute;gale &agrave; la valeur
	sp&eacute;cifi&eacute;e</td></tr>
    </table>

    <example><title>Exemple</title>
      <highlight language="config">
&lt;IfVersion >= 2.3&gt;
    # la condition n'est satisfaite que pour les versions de httpd
	# sup&eacute;rieures ou &eacute;gales &agrave; 2.3
&lt;/IfVersion&gt;
      </highlight>
    </example>

    <p>En plus d'une comparaison num&eacute;rique, il est possible de comparer
    la version de httpd avec une <glossary ref="regex">expression
    rationnelle</glossary>. Il existe deux m&eacute;thodes pour sp&eacute;cifier cette
    derni&egrave;re :</p>

    <table style="zebra" border="1">
    <tr><th><var>op&eacute;rateur</var></th><th>description</th></tr>
    <tr><td><code>=</code> ou <code>==</code></td>
        <td><var>version</var> est de la forme
            <code>/<var>regex</var>/</code></td></tr>
    <tr><td><code>~</code></td>
        <td><var>version</var> est de la forme
            <code><var>regex</var></code></td></tr>
    </table>

    <example><title>Exemple</title>
      <highlight language="config">
&lt;IfVersion = /^2.4.[01234]$/&gt;
    # exemple de contournement pour les versions bogu&eacute;es
&lt;/IfVersion&gt;
      </highlight>
    </example>

    <p>Pour inverser la condition, tous les op&eacute;rateurs peuvent &ecirc;tre
    pr&eacute;fix&eacute;s par un point d'exclamation (<code>!</code>) :</p>

    <example>
     <highlight language="config">
&lt;IfVersion !~ ^2.4.[01234]$&gt;
    # pas pour ces versions
&lt;/IfVersion&gt;
    </highlight>
    </example>

    <p>Si <var>op&eacute;rateur</var> est absent, sa valeur implicite est
    <code>=</code>.</p>
</usage>
</directivesynopsis>

</modulesynopsis>
